@@ -24,8 +24,8 @@ use PHPMD\Rule\MethodAware;
 /**
  * This rule class detects methods not named in camelCase.
  *
- * @author    Francis Besset <francis.besset@gmail.com>
- * @since     1.1.0
+ * @author Francis Besset <francis.besset@gmail.com>
+ * @since 1.1.0
  */
 class CamelCaseMethodName extends AbstractRule implements MethodAware
 {
@@ -71,7 +71,7 @@ class CamelCaseMethodName extends AbstractRule implements MethodAware
         }
     }
 
-    private function isValid($methodName)
+    protected function isValid($methodName)
     {
         if ($this->getBooleanProperty('allow-underscore-test') && strpos($methodName, 'test') === 0) {
             return preg_match('/^test[a-zA-Z0-9]*([_][a-z][a-zA-Z0-9]*)?$/', $methodName);
