@@ -48,7 +48,7 @@ class LongParameterList extends AbstractRule implements FunctionAware, MethodAwa
                 $node->getType(),
                 $node->getName(),
                 $count,
-                $threshold
+                $threshold,
             )
         );
     }
