@@ -23,7 +23,7 @@ use PHPMD\TextUI\Command;
 /**
  * Integration tests for the coupling between objects rule class.
  *
- * @since      1.1.0
+ * @since 1.1.0
  */
 class CouplingBetweenObjectsIntegrationTest extends AbstractTest
 {
@@ -44,7 +44,7 @@ class CouplingBetweenObjectsIntegrationTest extends AbstractTest
                 'text',
                 'design',
                 '--reportfile',
-                $file
+                $file,
             )
         );
 
