@@ -34,7 +34,7 @@ class ExitExpressionTest extends AbstractTest
     public function testRuleNotAppliesToMethodWithoutExitExpression()
     {
         $rule = new ExitExpression();
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -46,7 +46,7 @@ class ExitExpressionTest extends AbstractTest
     public function testRuleAppliesToMethodWithExitExpression()
     {
         $rule = new ExitExpression();
-        $rule->setReport($this->getReportMock(1));
+        $rule->setReport($this->getReportWithOneViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -70,7 +70,7 @@ class ExitExpressionTest extends AbstractTest
     public function testRuleNotAppliesToFunctionWithoutExitExpression()
     {
         $rule = new ExitExpression();
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getFunction());
     }
 
@@ -82,7 +82,7 @@ class ExitExpressionTest extends AbstractTest
     public function testRuleAppliesToFunctionWithExitExpression()
     {
         $rule = new ExitExpression();
-        $rule->setReport($this->getReportMock(1));
+        $rule->setReport($this->getReportWithOneViolation());
         $rule->apply($this->getFunction());
     }
 
