@@ -36,7 +36,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 54);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(1));
+        $rule->setReport($this->getReportWithOneViolation());
         $rule->apply($this->getFunction());
     }
 
@@ -50,7 +50,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 52);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getFunction());
     }
 
@@ -64,9 +64,10 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 54);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getFunction());
     }
+
     /**
      * testRuleAppliesToFunctionWithNameShorterThanThreshold
      *
@@ -77,7 +78,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 52);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(1));
+        $rule->setReport($this->getReportWithOneViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -91,7 +92,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 50);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -105,7 +106,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 52);
         $rule->addProperty('exceptions', '');
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -119,7 +120,7 @@ class ShortMethodNameTest extends AbstractTest
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 100);
         $rule->addProperty('exceptions', 'testRuleNotAppliesToMethodWithShortNameWhenException,another');
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getMethod());
     }
 
@@ -135,7 +136,7 @@ class ShortMethodNameTest extends AbstractTest
     {
         $rule = new ShortMethodName();
         $rule->addProperty('minimum', 100);
-        $rule->setReport($this->getReportMock(0));
+        $rule->setReport($this->getReportWithNoViolation());
         $rule->apply($this->getMethodMock());
     }
 }
