@@ -21,7 +21,9 @@ class testNamespacedCompactFunctionRuleWorksCaseInsensitive
 {
     public function testNamespacedCompactFunctionRuleWorksCaseInsensitive()
     {
-        $foo = 1; $bar = 2; $baz = 0;
+        $foo = 1;
+        $bar = 2;
+        $baz = 0;
 
         return Compact('foo', 'bar', 'baz');
     }
